import { ComponentStateColorPalette, parseColorHexRGB } from '@microsoft/fast-colors';
import { html } from '@microsoft/fast-element';
import { accordionIcons } from '../../styles';
const targetValue = (ctx) => ctx.event.target.value;
const createColorPalette = (baseColor) => new ComponentStateColorPalette({
    baseColor,
}).palette.map((color) => color.toStringHexRGB().toUpperCase());
// const fractionDigits = 2;
// const neutralLayerL1Behavior = neutralLayer1.createBehavior();
export const template = html `
  <zero-card>
    <h2>Design System Properties</h2>
    <div class="row">
      <h4>Corner Radius: ${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.cornerRadius; }}px</h4>
      <fast-slider
        orientation="horizontal"
        min="0"
        max="50"
        step="1"
        :value=${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.cornerRadius; }}
        @change=${(x, c) => (x.provider.cornerRadius = targetValue(c))}
      >
        <fast-slider-label position="0">0px</fast-slider-label>
        <fast-slider-label position="50">50px</fast-slider-label>
      </fast-slider>
    </div>

    <div class="row">
      <h4>Disabled Opacity: ${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.disabledOpacity; }}%</h4>
      <fast-slider
        orientation="horizontal"
        min="0"
        max="1"
        step="0.01"
        :value=${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.disabledOpacity; }}
        @change=${(x, c) => {
    // (x.provider.disabledOpacity = parseFloat(targetValue(c)).toFixed(2))
}}
      >
        <fast-slider-label position="0">0%</fast-slider-label>
        <fast-slider-label position="100">100%</fast-slider-label>
      </fast-slider>
    </div>

    <div class="row">
      <h4>Base Layer Luminance: ${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.baseLayerLuminance; }}</h4>
      <fast-slider
        orientation="horizontal"
        min="0"
        max="1"
        step="0.01"
        :value=${(x) => { var _a; return parseFloat((_a = x.provider) === null || _a === void 0 ? void 0 : _a.baseLayerLuminance); }}
        @change=${(x, c) => {
    // x.provider.backgroundColor = (neutralLayerL1Behavior as any)({
    //   ...x.provider.designSystem,
    // });
    // x.provider.baseLayerLuminance = parseFloat(targetValue(c)).toFixed(2);
}}
      >
        <fast-slider-label position="0">Black</fast-slider-label>
        <fast-slider-label position="0.23">Dark</fast-slider-label>
        <fast-slider-label position="1">Light</fast-slider-label>
      </fast-slider>
    </div>

    <div class="row tight">
      <h4>Accent Color</h4>
      <input
        type="color"
        :value=${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.accentBaseColor; }}
        @input=${(x, c) => {
    x.provider.accentBaseColor = targetValue(c);
    x.provider.accentPalette = createColorPalette(parseColorHexRGB(targetValue(c)));
}}
      />
    </div>

    <div class="row tight">
      <h4>Design Unit</h4>
      <zero-text-field
        type="number"
        :value=${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.designUnit; }}
        @change=${(x, c) => (x.provider.designUnit = targetValue(c))}
      ></zero-text-field>
    </div>

    <div class="row tight">
      <h4>Outline Width</h4>
      <zero-text-field
        type="number"
        :value=${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.outlineWidth; }}
        @input=${(x, c) => (x.provider.outlineWidth = targetValue(c))}
      ></zero-text-field>
    </div>
  </zero-card>
`;
/**
 * TODO: Fix initial value bug. It's overriding the design system value for cornerRadius when mounted.
 */
export const cornerRadius = `
<fast-accordion class="accordion-top-in-set">
    <fast-accordion-item expanded>
        <h3 slot="heading">Corner Radius: <b>${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.cornerRadius; }}px</b></h3>
            ${accordionIcons}
        <fast-slider
            orientation="horizontal"
            min="0"
            max="16"
            step="4"
            :value=${(x) => { var _a; return (_a = x.provider) === null || _a === void 0 ? void 0 : _a.cornerRadius; }}
            @change=${(x, c) => (x.provider.cornerRadius = targetValue(c))}
        >
            <fast-slider-label position="0">0px</fast-slider-label>
            <fast-slider-label position="16">16px</fast-slider-label>
        </fast-slider>
    </fast-accordion-item>
</fast-accordion>
`;
